@@ -1,3 +1,5 @@
+//! basic auth middleware
+
 use async_trait::async_trait;
 
 use salvo_core::http::header::AUTHORIZATION;
@@ -7,56 +9,63 @@ use salvo_core::Handler;
 
 use thiserror::Error;
 
+/// key used when insert into depot.
+pub const USERNAME_KEY: &str = "::salvo::extra::basic_auth::username";
+
+/// Error
 #[derive(Debug, Error)]
 pub enum Error {
-    #[error("Base64 decode error.")]
+    /// Base64 decode error
+    #[error("Base64 decode error")]
     Base64Decode(#[from] base64::DecodeError),
+    /// ParseHttpHeader
     #[error("Parse http header error")]
     ParseHttpHeader,
 }
 
+/// BasicAuthValidator
 pub trait BasicAuthValidator: Send + Sync {
-    fn validate(&self, name: String, password: String) -> bool;
+    /// Validate is that username and password is right.
+    fn validate(&self, username: String, password: String) -> bool;
 }
 impl<F> BasicAuthValidator for F
 where
     F: Send + Sync,
     F: Fn(String, String) -> bool,
 {
-    fn validate(&self, name: String, password: String) -> bool {
-        self(name, password)
+    fn validate(&self, username: String, password: String) -> bool {
+        self(username, password)
     }
 }
 
+/// BasicAuthDepotExt
+pub trait BasicAuthDepotExt {
+    /// Get basic auth username reference.
+    fn basic_auth_username(&self) -> Option<&String>;
+}
+
+impl BasicAuthDepotExt for Depot {
+    fn basic_auth_username(&self) -> Option<&String> {
+        self.try_borrow(USERNAME_KEY)
+    }
+}
+
+/// BasicAuthHandler
 pub struct BasicAuthHandler<V: BasicAuthValidator> {
     realm: String,
-    context_key: Option<String>,
     validator: V,
 }
 impl<V> BasicAuthHandler<V>
 where
     V: BasicAuthValidator,
 {
+    /// Create new `BasicAuthValidator`.
     pub fn new(validator: V) -> Self {
         BasicAuthHandler {
             realm: "realm".to_owned(),
-            context_key: None,
             validator,
         }
     }
-    #[inline]
-    pub fn context_key(&self) -> Option<&String> {
-        self.context_key.as_ref()
-    }
-    #[inline]
-    pub fn set_context_key(&mut self, context_key: Option<String>) {
-        self.context_key = context_key;
-    }
-    #[inline]
-    pub fn with_context_key(mut self, context_key: Option<String>) -> Self {
-        self.context_key = context_key;
-        self
-    }
 
     #[inline]
     fn ask_credentials(&self, res: &mut Response) {
@@ -88,11 +97,9 @@ where
             if let Ok(auth) = auth.to_str() {
                 if auth.starts_with("Basic") {
                     if let Some(auth) = auth.splitn(2, ' ').collect::<Vec<&str>>().pop() {
-                        if let Ok((user_name, password)) = self.parse_authorization(auth) {
-                            if self.validator.validate(user_name.clone(), password) {
-                                if let Some(key) = &self.context_key {
-                                    depot.insert(key.clone(), user_name);
-                                }
+                        if let Ok((username, password)) = self.parse_authorization(auth) {
+                            if self.validator.validate(username.clone(), password) {
+                                depot.insert(USERNAME_KEY, username);
                                 return;
                             }
                         }
@@ -115,8 +122,7 @@ mod tests {
     #[tokio::test]
     async fn test_basic_auth() {
         let auth_handler =
-            BasicAuthHandler::new(|user_name, password| -> bool { user_name == "root" && password == "pwd" })
-                .with_context_key(Some("user_name".to_owned()));
+            BasicAuthHandler::new(|username, password| -> bool { username == "root" && password == "pwd" });
 
         #[fn_handler]
         async fn hello() -> &'static str {
@@ -128,22 +134,22 @@ mod tests {
             .push(Router::with_path("hello").get(hello));
         let service = Service::new(router);
 
-        let mut request = hyper::Request::builder()
+        let mut req = hyper::Request::builder()
             .method("GET")
             .uri("http://127.0.0.1:7979/hello");
-        let headers = request.headers_mut().unwrap();
+        let headers = req.headers_mut().unwrap();
         headers.typed_insert(Authorization::basic("root", "pwd"));
-        let request = Request::from_hyper(request.body(hyper::Body::empty()).unwrap());
-        let content = service.handle(request).await.take_text().await.unwrap();
+        let req: Request = req.body(hyper::Body::empty()).unwrap().into();
+        let content = service.handle(req).await.take_text().await.unwrap();
         assert!(content.contains("hello"));
 
-        let mut request = hyper::Request::builder()
+        let mut req = hyper::Request::builder()
             .method("GET")
             .uri("http://127.0.0.1:7979/hello");
-        let headers = request.headers_mut().unwrap();
+        let headers = req.headers_mut().unwrap();
         headers.typed_insert(Authorization::basic("root", "pwd2"));
-        let request = Request::from_hyper(request.body(hyper::Body::empty()).unwrap());
-        let content = service.handle(request).await.take_text().await.unwrap();
+        let req: Request = req.body(hyper::Body::empty()).unwrap().into();
+        let content = service.handle(req).await.take_text().await.unwrap();
         assert!(content.contains("Unauthorized"));
     }
 }
