@@ -8,10 +8,14 @@ use salvo_core::prelude::*;
 use tokio_stream::{self, StreamExt};
 use tokio_util::io::{ReaderStream, StreamReader};
 
+/// CompressionAlgo
 #[derive(Clone, Copy, Debug)]
 pub enum CompressionAlgo {
+    /// Brotli
     Brotli,
+    /// Deflate
     Deflate,
+    /// Gzip
     Gzip,
 }
 
@@ -26,6 +30,7 @@ impl From<CompressionAlgo> for HeaderValue {
     }
 }
 
+/// CompressionHandler
 #[derive(Clone, Debug)]
 pub struct CompressionHandler {
     algo: CompressionAlgo,
@@ -41,6 +46,7 @@ impl Default for CompressionHandler {
 }
 
 impl CompressionHandler {
+    /// Create a new `CompressionHandler`.
     #[inline]
     pub fn new(algo: CompressionAlgo) -> Self {
         CompressionHandler {
@@ -56,36 +62,42 @@ impl CompressionHandler {
             min_length: 1024,
         }
     }
+    /// Create a new `CompressionHandler` with algo.
     #[inline]
     pub fn with_algo(mut self, algo: CompressionAlgo) -> Self {
         self.algo = algo;
         self
     }
 
+    /// get min_length.
     #[inline]
     pub fn min_length(&mut self) -> usize {
         self.min_length
     }
-    // Set minimum compression size, if body less than this value, no compression
-    // default is 1kb
+    /// Set minimum compression size, if body less than this value, no compression
+    /// default is 1kb
     #[inline]
     pub fn set_min_length(&mut self, size: usize) {
         self.min_length = size;
     }
+    /// Create a new `CompressionHandler` with min_length.
     #[inline]
     pub fn with_min_length(mut self, min_length: usize) -> Self {
         self.min_length = min_length;
         self
     }
 
+    /// Get content type list reference.
     #[inline]
     pub fn content_types(&self) -> &Vec<String> {
         &self.content_types
     }
+    /// Get content type list mutable reference.
     #[inline]
     pub fn content_types_mut(&mut self) -> &mut Vec<String> {
         &mut self.content_types
     }
+    /// Create a new `CompressionHandler` with content types list.
     #[inline]
     pub fn with_content_types(mut self, content_types: &[String]) -> Self {
         self.content_types = content_types.to_vec();
@@ -230,13 +242,15 @@ mod tests {
         let router = Router::with_after(comp_handler).push(Router::with_path("hello").get(hello));
         let service = Service::new(router);
 
-        let request = hyper::Request::builder()
+        let req: Request = hyper::Request::builder()
             .method("GET")
-            .uri("http://127.0.0.1:7979/hello");
-        let request = Request::from_hyper(request.body(hyper::Body::empty()).unwrap());
-        let mut response = service.handle(request).await;
-        assert_eq!(response.headers().get("content-encoding").unwrap(), "gzip");
-        let content = response.take_text().await.unwrap();
+            .uri("http://127.0.0.1:7979/hello")
+            .body(hyper::Body::empty())
+            .unwrap()
+            .into();
+        let mut res = service.handle(req).await;
+        assert_eq!(res.headers().get("content-encoding").unwrap(), "gzip");
+        let content = res.take_text().await.unwrap();
         assert_eq!(content, "hello");
     }
 
@@ -246,13 +260,15 @@ mod tests {
         let router = Router::with_after(comp_handler).push(Router::with_path("hello").get(hello));
         let service = Service::new(router);
 
-        let request = hyper::Request::builder()
+        let req: Request = hyper::Request::builder()
             .method("GET")
-            .uri("http://127.0.0.1:7979/hello");
-        let request = Request::from_hyper(request.body(hyper::Body::empty()).unwrap());
-        let mut response = service.handle(request).await;
-        assert_eq!(response.headers().get("content-encoding").unwrap(), "br");
-        let content = response.take_text().await.unwrap();
+            .uri("http://127.0.0.1:7979/hello")
+            .body(hyper::Body::empty())
+            .unwrap()
+            .into();
+        let mut res = service.handle(req).await;
+        assert_eq!(res.headers().get("content-encoding").unwrap(), "br");
+        let content = res.take_text().await.unwrap();
         assert_eq!(content, "hello");
     }
 
@@ -265,10 +281,10 @@ mod tests {
         let request = hyper::Request::builder()
             .method("GET")
             .uri("http://127.0.0.1:7979/hello");
-        let request = Request::from_hyper(request.body(hyper::Body::empty()).unwrap());
-        let mut response = service.handle(request).await;
-        assert_eq!(response.headers().get("content-encoding").unwrap(), "deflate");
-        let content = response.take_text().await.unwrap();
+        let req: Request = request.body(hyper::Body::empty()).unwrap().into();
+        let mut res = service.handle(req).await;
+        assert_eq!(res.headers().get("content-encoding").unwrap(), "deflate");
+        let content = res.take_text().await.unwrap();
         assert_eq!(content, "hello");
     }
 }
