@@ -53,6 +53,7 @@ impl Default for HandlerBuilder {
 }
 
 impl HandlerBuilder {
+    /// Create new `HandlerBuilder`.
     pub fn new() -> Self {
         HandlerBuilder {
             credentials: false,
@@ -318,6 +319,7 @@ enum Validated {
     NotCors,
 }
 
+/// CorsHandler
 #[derive(Debug)]
 pub struct CorsHandler {
     credentials: bool,
@@ -331,6 +333,7 @@ pub struct CorsHandler {
     methods_header: AccessControlAllowMethods,
 }
 impl CorsHandler {
+    /// Return `HandlerBuilder` instance for build `CorsHandler`.
     #[inline]
     pub fn builder() -> HandlerBuilder {
         HandlerBuilder::default()
@@ -449,7 +452,9 @@ impl Handler for CorsHandler {
     }
 }
 
+/// Seconds
 pub trait Seconds {
+    /// Get seconds.
     fn seconds(self) -> u64;
 }
 
@@ -467,7 +472,9 @@ impl Seconds for ::std::time::Duration {
     }
 }
 
+/// IntoOrigin
 pub trait IntoOrigin {
+    /// Convert to `Origin`.
     fn into_origin(self) -> Origin;
 }
 
@@ -514,42 +521,40 @@ mod tests {
         let service = Service::new(router);
 
         async fn options_access(service: &Service, origin: &str) -> Response {
-            let request = Request::from_hyper(
-                hyper::Request::builder()
-                    .method("OPTIONS")
-                    .uri("http://127.0.0.1:7979/hello")
-                    .header("Origin", origin)
-                    .header("Access-Control-Request-Method", "POST")
-                    .header("Access-Control-Request-Headers", "Content-Type")
-                    .body(hyper::Body::empty())
-                    .unwrap(),
-            );
-            service.handle(request).await
+            let req: Request = hyper::Request::builder()
+                .method("OPTIONS")
+                .uri("http://127.0.0.1:7979/hello")
+                .header("Origin", origin)
+                .header("Access-Control-Request-Method", "POST")
+                .header("Access-Control-Request-Headers", "Content-Type")
+                .body(hyper::Body::empty())
+                .unwrap()
+                .into();
+            service.handle(req).await
         }
 
         async fn access(service: &Service, method: &str, origin: &str) -> Response {
-            let request = Request::from_hyper(
-                hyper::Request::builder()
-                    .method(method)
-                    .uri("http://127.0.0.1:7979/hello")
-                    .header("Origin", origin)
-                    .body(hyper::Body::empty())
-                    .unwrap(),
-            );
-            service.handle(request).await
+            let req: Request = hyper::Request::builder()
+                .method(method)
+                .uri("http://127.0.0.1:7979/hello")
+                .header("Origin", origin)
+                .body(hyper::Body::empty())
+                .unwrap()
+                .into();
+            service.handle(req).await
         }
 
-        let response = access(&service, "OPTIONS", "https://salvo.rs").await;
-        let headers = response.headers();
+        let res = access(&service, "OPTIONS", "https://salvo.rs").await;
+        let headers = res.headers();
         assert!(headers.get(ACCESS_CONTROL_ALLOW_METHODS).is_none());
 
-        let response = options_access(&service, "https://salvo.rs").await;
-        let headers = response.headers();
+        let res = options_access(&service, "https://salvo.rs").await;
+        let headers = res.headers();
         assert!(headers.get(ACCESS_CONTROL_ALLOW_METHODS).is_some());
         assert!(headers.get(ACCESS_CONTROL_ALLOW_HEADERS).is_some());
 
-        let response = access(&service, "OPTIONS", "https://google.com").await;
-        let headers = response.headers();
+        let res = access(&service, "OPTIONS", "https://google.com").await;
+        let headers = res.headers();
         assert!(
             headers.get(ACCESS_CONTROL_ALLOW_METHODS).is_none(),
             "POST, GET, DELETE, OPTIONS"
