@@ -1,8 +1,11 @@
+//! size limiter middleware
+
 use async_trait::async_trait;
 use salvo_core::http::errors::*;
 use salvo_core::http::HttpBody;
 use salvo_core::prelude::*;
 
+/// MaxSizeHandler
 pub struct MaxSizeHandler(u64);
 #[async_trait]
 impl Handler for MaxSizeHandler {
@@ -14,7 +17,7 @@ impl Handler for MaxSizeHandler {
         }
     }
 }
-
+/// Create a new ```MaxSizeHandler```.
 pub fn max_size(size: u64) -> MaxSizeHandler {
     MaxSizeHandler(size)
 }
@@ -39,24 +42,22 @@ mod tests {
             .push(Router::with_path("hello").post(hello));
         let service = Service::new(router);
 
-        let request = Request::from_hyper(
-            hyper::Request::builder()
-                .method("POST")
-                .uri("http://127.0.0.1:7979/hello")
-                .body("abc".into())
-                .unwrap(),
-        );
-        let content = service.handle(request).await.take_text().await.unwrap();
+        let req: Request = hyper::Request::builder()
+            .method("POST")
+            .uri("http://127.0.0.1:7979/hello")
+            .body("abc".into())
+            .unwrap()
+            .into();
+        let content = service.handle(req).await.take_text().await.unwrap();
         assert_eq!(content, "hello");
 
-        let request = Request::from_hyper(
-            hyper::Request::builder()
-                .method("POST")
-                .uri("http://127.0.0.1:7979/hello")
-                .body("abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz".into())
-                .unwrap(),
-        );
-        let response = service.handle(request).await;
-        assert_eq!(response.status_code(), Some(StatusCode::PAYLOAD_TOO_LARGE));
+        let req: Request = hyper::Request::builder()
+            .method("POST")
+            .uri("http://127.0.0.1:7979/hello")
+            .body("abcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyzabcdefghijklmnopqrstuvwxyz".into())
+            .unwrap()
+            .into();
+        let res = service.handle(req).await;
+        assert_eq!(res.status_code().unwrap(), StatusCode::PAYLOAD_TOO_LARGE);
     }
 }
