@@ -64,13 +64,13 @@ use tokio::time::{self, Sleep};
 
 use salvo_core::http::Response;
 
-// Server-sent event data type
+/// Server-sent event data type
 #[derive(Debug)]
 enum DataType {
     Text(String),
     Json(String),
 }
-
+/// SseError
 #[derive(Debug)]
 pub struct SseError;
 
@@ -200,6 +200,7 @@ impl Display for SseEvent {
     }
 }
 
+/// SseKeepAlive
 #[allow(missing_debug_implementations)]
 #[pin_project]
 pub struct SseKeepAlive<S> {
@@ -216,6 +217,7 @@ where
     S: TryStream<Ok = SseEvent> + Send + 'static,
     S::Error: StdError + Send + Sync + 'static,
 {
+    /// Create new `SseKeepAlive`.
     pub fn new(event_stream: S) -> SseKeepAlive<S> {
         let max_interval = Duration::from_secs(15);
         let alive_timer = time::sleep(max_interval);
@@ -264,6 +266,7 @@ fn write_request_headers(res: &mut Response) {
         .insert(CACHE_CONTROL, HeaderValue::from_static("no-cache"));
 }
 
+/// Streaming
 pub fn streaming<S>(res: &mut Response, event_stream: S)
 where
     S: TryStream<Ok = SseEvent> + Send + 'static,
@@ -329,21 +332,21 @@ mod tests {
             Ok::<_, Infallible>(SseEvent::default().data("1")),
             Ok::<_, Infallible>(SseEvent::default().data("2")),
         ]);
-        let mut response = Response::new();
-        super::streaming(&mut response, event_stream);
-        let text = response.take_text().await.unwrap();
+        let mut res = Response::new();
+        super::streaming(&mut res, event_stream);
+        let text = res.take_text().await.unwrap();
         assert!(text.contains("data:1") && text.contains("data:2"));
     }
 
     #[tokio::test]
     async fn test_sse_keep_alive() {
         let event_stream = tokio_stream::iter(vec![Ok::<_, Infallible>(SseEvent::default().data("1"))]);
-        let mut response = Response::new();
+        let mut res = Response::new();
         SseKeepAlive::new(event_stream)
             .with_comment("love you")
             .with_interval(Duration::from_secs(1))
-            .streaming(&mut response);
-        let text = response.take_text().await.unwrap();
+            .streaming(&mut res);
+        let text = res.take_text().await.unwrap();
         assert!(text.contains("data:1"));
     }
 
@@ -357,27 +360,27 @@ mod tests {
         let event_stream = tokio_stream::iter(vec![SseEvent::default().json_data(User {
             name: "jobs".to_owned(),
         })]);
-        let mut response = Response::new();
-        super::streaming(&mut response, event_stream);
-        let text = response.take_text().await.unwrap();
+        let mut res = Response::new();
+        super::streaming(&mut res, event_stream);
+        let text = res.take_text().await.unwrap();
         assert!(text.contains(r#"data:{"name":"jobs"}"#));
     }
 
     #[tokio::test]
     async fn test_sse_comment() {
         let event_stream = tokio_stream::iter(vec![Ok::<_, Infallible>(SseEvent::default().comment("comment"))]);
-        let mut response = Response::new();
-        super::streaming(&mut response, event_stream);
-        let text = response.take_text().await.unwrap();
+        let mut res = Response::new();
+        super::streaming(&mut res, event_stream);
+        let text = res.take_text().await.unwrap();
         assert!(text.contains(":comment"));
     }
 
     #[tokio::test]
     async fn test_sse_name() {
         let event_stream = tokio_stream::iter(vec![Ok::<_, Infallible>(SseEvent::default().name("evt2"))]);
-        let mut response = Response::new();
-        super::streaming(&mut response, event_stream);
-        let text = response.take_text().await.unwrap();
+        let mut res = Response::new();
+        super::streaming(&mut res, event_stream);
+        let text = res.take_text().await.unwrap();
         assert!(text.contains("event:evt2"));
     }
 
@@ -386,26 +389,26 @@ mod tests {
         let event_stream = tokio_stream::iter(vec![Ok::<_, Infallible>(
             SseEvent::default().retry(std::time::Duration::from_secs_f32(1.02)),
         )]);
-        let mut response = Response::new();
-        super::streaming(&mut response, event_stream);
-        let text = response.take_text().await.unwrap();
+        let mut res = Response::new();
+        super::streaming(&mut res, event_stream);
+        let text = res.take_text().await.unwrap();
         assert!(text.contains("retry:1020"));
 
         let event_stream = tokio_stream::iter(vec![Ok::<_, Infallible>(
             SseEvent::default().retry(std::time::Duration::from_secs_f32(1.001)),
         )]);
-        let mut response = Response::new();
-        super::streaming(&mut response, event_stream);
-        let text = response.take_text().await.unwrap();
+        let mut res = Response::new();
+        super::streaming(&mut res, event_stream);
+        let text = res.take_text().await.unwrap();
         assert!(text.contains("retry:1001"));
     }
 
     #[tokio::test]
     async fn test_sse_id() {
         let event_stream = tokio_stream::iter(vec![Ok::<_, Infallible>(SseEvent::default().id("jobs"))]);
-        let mut response = Response::new();
-        super::streaming(&mut response, event_stream);
-        let text = response.take_text().await.unwrap();
+        let mut res = Response::new();
+        super::streaming(&mut res, event_stream);
+        let text = res.take_text().await.unwrap();
         assert!(text.contains("id:jobs"));
     }
 }
